%define api		1.0
%define major		0

%define bname		gstreamer%{api}
%define libname		%mklibname gstreamer-plugins-base %{api} %{major}
%define girname		%mklibname gstreamer-plugins-base-gir %{api}
%define develname	%mklibname -d gstreamer-plugins-base %{api}

%define libgstgl	%mklibname gstgl %{api} %{major}
%define gstglgir	%mklibname gstgl-gir %{api}

# Disabled as we don't have hotdoc
%bcond_with docs

Summary:	GStreamer Streaming-media framework plug-ins
Name:		%{bname}-plugins-base
Version:	1.22.11
Release:	%mkrel 1
License:	LGPLv2+
Group:		Sound/Utilities
URL:		https://gstreamer.freedesktop.org/
Source:		https://gstreamer.freedesktop.org/src/gst-plugins-base/gst-plugins-base-%{version}.tar.xz
Patch0:		align.patch
Patch1:		gst-plugins-base-meson-nosse.patch
BuildRequires:	cmake
BuildRequires:	git-core
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(graphene-1.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(gtk+-x11-3.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libvisual-0.4)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(orc-0.4)
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(pangocairo)
BuildRequires:	pkgconfig(theoradec)
BuildRequires:	pkgconfig(theoraenc)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(vorbisenc)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(ice)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(wayland-protocols)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xv)
BuildRequires:	pkgconfig(xext)
BuildRequires:	libcdda-devel
BuildRequires:	gstreamer%{api}-devel >= %{version}
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	gettext-devel
%if %{with docs}
BuildRequires:	gtk-doc
%endif
BuildRequires:	iso-codes
#gw we need some fonts for the tests
BuildRequires:	fonts-ttf-dejavu
BuildRequires:	pkgconfig(check)
BuildRequires:	meson
Provides:	%{bname}-plugins

%ifarch %ix86
BuildRequires:	nasm >= 0.90
%endif

%ifarch %{valgrind_arches}
BuildRequires:	pkgconfig(valgrind)
%endif

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This package contains a set of reference plugins, base classes for other
plugins, and helper libraries:
 * device plugins: x(v)imagesink, alsa, v4lsrc, cdparanoia
 * containers: ogg
 * codecs: vorbis, theora
 * text: textoverlay, subparse
 * sources: audiotestsrc, videotestsrc, gnomevfssrc
 * network: tcp
 * typefind
 * audio processing: audioconvert, adder, audiorate, audioscale, volume
 * visualisation: libvisual
 * video processing: ffmpegcolorspace
 * aggregate elements: decodebin, playbin

%prep
%setup -q -n gst-plugins-base-%{version}
%patch0 -p1
%ifarch %{ix86}
%patch1 -p1
%endif

%build
%meson \
	-Dgl_winsys='x11,wayland' \
	-Ddoc=%{?_with_docs:enabled}%{?!_with_docs:disabled} \
	-Dtremor=disabled \
	-Dexamples=disabled \
	-Dtests=disabled \
	-Dlibvisual=enabled \
	-Dorc=enabled \
	-Diso-codes=enabled \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/'

%meson_build

%install
%meson_install

%find_lang gst-plugins-base-%{api}

%files -f gst-plugins-base-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%{_bindir}/gst-discoverer-%{api}
%{_bindir}/gst-device-monitor-%{api}
%{_bindir}/gst-play-%{api}
%{_mandir}/man1/gst-discoverer-%{api}.1.*
%{_mandir}/man1/gst-device-monitor-%{api}.1.*
%{_mandir}/man1/gst-play-%{api}.1.*
# non-core plugins without external dependencies
%{_libdir}/gstreamer-%{api}/libgstapp.so
%{_libdir}/gstreamer-%{api}/libgstaudioconvert.so
%{_libdir}/gstreamer-%{api}/libgstaudiomixer.so
%{_libdir}/gstreamer-%{api}/libgstaudiorate.so
%{_libdir}/gstreamer-%{api}/libgstaudioresample.so
%{_libdir}/gstreamer-%{api}/libgstaudiotestsrc.so
%{_libdir}/gstreamer-%{api}/libgstcompositor.so
%{_libdir}/gstreamer-%{api}/libgstencoding.so
%{_libdir}/gstreamer-%{api}/libgstgio.so
%{_libdir}/gstreamer-%{api}/libgstpbtypes.so
%{_libdir}/gstreamer-%{api}/libgstpango.so
%{_libdir}/gstreamer-%{api}/libgstrawparse.so
%{_libdir}/gstreamer-%{api}/libgstsubparse.so
%{_libdir}/gstreamer-%{api}/libgsttcp.so
%{_libdir}/gstreamer-%{api}/libgstvolume.so
%{_libdir}/gstreamer-%{api}/libgstadder.so
%{_libdir}/gstreamer-%{api}/libgsttypefindfunctions.so
%{_libdir}/gstreamer-%{api}/libgstvideotestsrc.so
%{_libdir}/gstreamer-%{api}/libgsttheora.so
%{_libdir}/gstreamer-%{api}/libgstogg.so
%{_libdir}/gstreamer-%{api}/libgstopengl.so
%{_libdir}/gstreamer-%{api}/libgstopus.so
%{_libdir}/gstreamer-%{api}/libgstoverlaycomposition.so
%{_libdir}/gstreamer-%{api}/libgstvideorate.so
%{_libdir}/gstreamer-%{api}/libgstvorbis.so
%{_libdir}/gstreamer-%{api}/libgstximagesink.so
%{_libdir}/gstreamer-%{api}/libgstxvimagesink.so
%{_libdir}/gstreamer-%{api}/libgstalsa.so
%{_libdir}/gstreamer-%{api}/libgstplayback.so
%{_libdir}/gstreamer-%{api}/libgstvideoconvertscale.so

%package -n %{libname}
Group: 		System/Libraries
Summary: 	GStreamer plugin libraries

%description -n %{libname}
This package contain the basic audio and video playback library and
the interfaces library.

%files -n %{libname}
%{_libdir}/libgstallocators-%{api}.so.%{major}{,.*}
%{_libdir}/libgstapp-%{api}.so.%{major}{,.*}
%{_libdir}/libgstaudio-%{api}.so.%{major}{,.*}
%{_libdir}/libgstfft-%{api}.so.%{major}{,.*}
%{_libdir}/libgstpbutils-%{api}.so.%{major}{,.*}
%{_libdir}/libgstriff-%{api}.so.%{major}{,.*}
%{_libdir}/libgstrtp-%{api}.so.%{major}{,.*}
%{_libdir}/libgstrtsp-%{api}.so.%{major}{,.*}
%{_libdir}/libgstsdp-%{api}.so.%{major}{,.*}
%{_libdir}/libgsttag-%{api}.so.%{major}{,.*}
%{_libdir}/libgstvideo-%{api}.so.%{major}{,.*}

%package -n %{girname}
Group:		System/Libraries
Summary:	GObject Introspection interface description for %{name}
Requires:	%{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%files -n %{girname}
%{_libdir}/girepository-1.0/GstAllocators-%{api}.typelib
%{_libdir}/girepository-1.0/GstApp-%{api}.typelib
%{_libdir}/girepository-1.0/GstAudio-%{api}.typelib
%{_libdir}/girepository-1.0/GstPbutils-%{api}.typelib
%{_libdir}/girepository-1.0/GstRtp-%{api}.typelib
%{_libdir}/girepository-1.0/GstRtsp-%{api}.typelib
%{_libdir}/girepository-1.0/GstSdp-%{api}.typelib
%{_libdir}/girepository-1.0/GstTag-%{api}.typelib
%{_libdir}/girepository-1.0/GstVideo-%{api}.typelib

%package -n %{gstglgir}
Summary:	GObject Introspection interface description for GstGL
Group:		System/Libraries
Requires:	%{libgstgl} = %{version}-%{release}

%description -n %{gstglgir}
GObject Introspection interface description for GstGL.

%files -n %{gstglgir}
%{_libdir}/girepository-1.0/GstGL-%{api}.typelib
%{_libdir}/girepository-1.0/GstGLEGL-%{api}.typelib
%{_libdir}/girepository-1.0/GstGLWayland-%{api}.typelib
%{_libdir}/girepository-1.0/GstGLX11-%{api}.typelib

%package -n %{develname}
Summary: 	GStreamer Plugin Library Headers
Group: 		Development/C
Requires: 	%{libname} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	%{libgstgl} = %{version}-%{release}
Requires:	%{gstglgir} = %{version}-%{release}
Provides:	libgstreamer%{api}-plugins-base-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
GStreamer support libraries header files.

%files -n %{develname}
%if %{with docs}
%doc %{_datadir}/gtk-doc/html/*
%endif
%{_includedir}/gstreamer-%{api}/gst/*
%dir %{_libdir}/gstreamer-%{api}/include/
%dir %{_libdir}/gstreamer-%{api}/include/gst/
%dir %{_libdir}/gstreamer-%{api}/include/gst/gl/
%{_libdir}/gstreamer-%{api}/include/gst/gl/gstglconfig.h
%{_libdir}/pkgconfig/gstreamer-allocators-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-app-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-audio-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-fft-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-gl-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-gl-egl-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-gl-prototypes-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-gl-wayland-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-gl-x11-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-pbutils-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-plugins-base-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-riff-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-rtp-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-rtsp-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-sdp-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-tag-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-video-%{api}.pc
%{_libdir}/libgstallocators-%{api}.so
%{_libdir}/libgstaudio-%{api}.so
%{_libdir}/libgstapp-%{api}.so
%{_libdir}/libgstfft-%{api}.so
%{_libdir}/libgstgl-%{api}.so
%{_libdir}/libgstpbutils-%{api}.so
%{_libdir}/libgstriff-%{api}.so
%{_libdir}/libgstrtp-%{api}.so
%{_libdir}/libgstrtsp-%{api}.so
%{_libdir}/libgsttag-%{api}.so
%{_libdir}/libgstsdp-%{api}.so
%{_libdir}/libgstvideo-%{api}.so
%{_datadir}/gir-1.0/GstAllocators-%{api}.gir
%{_datadir}/gir-1.0/GstApp-%{api}.gir
%{_datadir}/gir-1.0/GstAudio-%{api}.gir
%{_datadir}/gir-1.0/GstGL-%{api}.gir
%{_datadir}/gir-1.0/GstGLEGL-%{api}.gir
%{_datadir}/gir-1.0/GstGLWayland-%{api}.gir
%{_datadir}/gir-1.0/GstGLX11-%{api}.gir
%{_datadir}/gir-1.0/GstPbutils-%{api}.gir
%{_datadir}/gir-1.0/GstRtp-%{api}.gir
%{_datadir}/gir-1.0/GstRtsp-%{api}.gir
%{_datadir}/gir-1.0/GstSdp-%{api}.gir
%{_datadir}/gir-1.0/GstTag-%{api}.gir
%{_datadir}/gir-1.0/GstVideo-%{api}.gir
%{_datadir}/gst-plugins-base/%{api}/license-translations.dict
###

### CDPARANOIA ###
%package -n %{bname}-cdparanoia
Summary:	Gstreamer plugin for CD audio input using CDParanoia IV
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description -n %{bname}-cdparanoia
Plugin for ripping audio tracks using cdparanoia under GStreamer.

%files -n %{bname}-cdparanoia
%{_libdir}/gstreamer-%{api}/libgstcdparanoia.so

%package -n %{bname}-libvisual
Summary:	GStreamer visualisations plug-in based on libvisual
Group:		Video/Utilities
Requires:	%{name} = %{version}-%{release}

%description -n %{bname}-libvisual
This plugin makes visualisations based on libvisual available for
GStreamer applications.

%files -n %{bname}-libvisual
%{_libdir}/gstreamer-%{api}/libgstlibvisual.so

%package -n %{libgstgl}
Summary:        Libraries for GStreamer streaming-media framework
Group:          System/Libraries

%description -n %{libgstgl}
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

This package contains the libraries.

%files -n %{libgstgl}
%{_libdir}/libgstgl-%{api}.so.%{major}{,.*}


%changelog
* Mon Apr 01 2024 ghibo <ghibo> 1.22.11-1.mga9
+ Revision: 2053606
- Update to version 1.22.11
- Update to release 1.22.8
- Update to release 1.22.5

* Sun May 21 2023 ghibo <ghibo> 1.22.3-1.mga9
+ Revision: 1957544
- Update to release 1.22.3

* Tue Jan 24 2023 wally <wally> 1.22.0-1.mga9
+ Revision: 1935696
- new version 1.22.0

* Sat Jan 14 2023 wally <wally> 1.21.90-1.mga9
+ Revision: 1933039
- new version 1.21.90

* Mon Dec 26 2022 wally <wally> 1.20.5-1.mga9
+ Revision: 1926955
- new version 1.20.5

* Sun Nov 20 2022 wally <wally> 1.20.4-1.mga9
+ Revision: 1909314
- new version 1.20.4

* Sat Jul 23 2022 wally <wally> 1.20.3-2.mga9
+ Revision: 1870430
- rebuild for core/release

* Sat Jul 23 2022 wally <wally> 1.20.3-1.mga9
+ Revision: 1870396
- new version 1.20.3

* Sun May 08 2022 wally <wally> 1.20.2-1.mga9
+ Revision: 1856820
- new version 1.20.2

* Sun Apr 03 2022 wally <wally> 1.20.1-1.mga9
+ Revision: 1841905
- new version 1.20.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Sep 18 2021 wally <wally> 1.18.5-1.mga9
+ Revision: 1745693
- new version 1.18.5 (mga#29452)

* Mon Apr 05 2021 wally <wally> 1.18.4-1.mga9
+ Revision: 1713700
- new version 1.18.4

* Thu Mar 11 2021 ghibo <ghibo> 1.18.3-2.mga9
+ Revision: 1701481
- Fix meson options to avoid illegal instructions (SSE, SSE2, SSE4.1) slipping in i586 pure architectures.

* Mon Jan 18 2021 wally <wally> 1.18.3-1.mga8
+ Revision: 1672335
- new version 1.18.3

* Wed Dec 09 2020 wally <wally> 1.18.2-1.mga8
+ Revision: 1655021
- new version 1.18.2

* Sat Nov 21 2020 wally <wally> 1.18.1-1.mga8
+ Revision: 1648142
- new version 1.18.1
- drop old conflicts

* Sun Sep 13 2020 wally <wally> 1.18.0-1.mga8
+ Revision: 1625689
- new version 1.18.0

* Fri Mar 13 2020 daviddavid <daviddavid> 1.16.2-2.mga8
+ Revision: 1555963
- switch to meson build system (GStreamer has given up on autotools...)
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Dec 04 2019 ovitters <ovitters> 1.16.2-1.mga8
+ Revision: 1464181
- new version 1.16.2

* Mon Sep 23 2019 ovitters <ovitters> 1.16.1-1.mga8
+ Revision: 1445152
- new version 1.16.1

* Sat Apr 27 2019 wally <wally> 1.16.0-2.mga7
+ Revision: 1395772
- add conflicts for files moved from plugins-bad devel

* Thu Apr 25 2019 wally <wally> 1.16.0-1.mga7
+ Revision: 1395266
- new version 1.16.0
- move gstcompositor from plugins-bad to plugins-base

* Thu Oct 04 2018 ovitters <ovitters> 1.14.4-1.mga7
+ Revision: 1317439
- new version 1.14.4

* Mon Sep 17 2018 ovitters <ovitters> 1.14.3-1.mga7
+ Revision: 1259414
- new version 1.14.3

* Fri Jul 20 2018 ovitters <ovitters> 1.14.2-1.mga7
+ Revision: 1244434
- new version 1.14.2

* Mon May 21 2018 wally <wally> 1.14.1-1.mga7
+ Revision: 1231137
- new version 1.14.1

* Sat Mar 24 2018 wally <wally> 1.14.0-2.mga7
+ Revision: 1212068
- new version 1.14.0
- gstgl and gstaudiomixer was moved to base from bad
- enable valgrind on all suppored arches

* Sat Dec 16 2017 wally <wally> 1.12.4-1.mga7
+ Revision: 1182805
- disable valgrind support on arm for now
- new version 1.12.4

* Tue Sep 26 2017 wally <wally> 1.12.3-2.mga7
+ Revision: 1160009
- rebuild for arm

* Sat Sep 23 2017 ovitters <ovitters> 1.12.3-1.mga7
+ Revision: 1157974
- new version 1.12.3

* Mon Jul 24 2017 wally <wally> 1.12.2-1.mga7
+ Revision: 1130362
- new version 1.12.2
- update pkg origin to match with other gst1.0 pkgs

* Mon Jul 17 2017 ovitters <ovitters> 1.10.5-1.mga7
+ Revision: 1124550
- new version 1.10.5

* Thu Feb 23 2017 ovitters <ovitters> 1.10.4-1.mga6
+ Revision: 1087466
- new version 1.10.4

* Mon Jan 30 2017 ovitters <ovitters> 1.10.3-1.mga6
+ Revision: 1084205
- new version 1.10.3

* Sat Jan 21 2017 akien <akien> 1.10.2-2.mga6
+ Revision: 1082681
- Rebuild for arm

* Sun Jan 15 2017 wally <wally> 1.10.2-1.mga6
+ Revision: 1081794
- new version 1.10.2

* Fri Aug 19 2016 luigiwalser <luigiwalser> 1.8.3-1.mga6
+ Revision: 1047095
- 1.8.3

* Fri Jun 10 2016 luigiwalser <luigiwalser> 1.8.2-1.mga6
+ Revision: 1021000
- 1.8.2

* Wed Jun 01 2016 luigiwalser <luigiwalser> 1.8.1-2.mga6
+ Revision: 1019650
- add conflicts to fix upgrade due to libgstopus.so

* Wed Apr 20 2016 ovitters <ovitters> 1.8.1-1.mga6
+ Revision: 1003809
- new version 1.8.1

* Thu Mar 24 2016 wally <wally> 1.8.0-2.mga6
+ Revision: 995179
- rebuild for arm

* Thu Mar 24 2016 ovitters <ovitters> 1.8.0-1.mga6
+ Revision: 994919
- new version 1.8.0

* Sat Mar 19 2016 wally <wally> 1.7.91-2.mga6
+ Revision: 992931
- build opus plugin

* Tue Mar 15 2016 ovitters <ovitters> 1.7.91-1.mga6
+ Revision: 990916
- new version 1.7.91

* Tue Mar 01 2016 ovitters <ovitters> 1.7.90-1.mga6
+ Revision: 981735
- new version 1.7.90

* Sat Jan 23 2016 luigiwalser <luigiwalser> 1.6.3-1.mga6
+ Revision: 926689
- 1.6.3

* Mon Dec 14 2015 ovitters <ovitters> 1.6.2-1.mga6
+ Revision: 910462
- new version 1.6.2

* Fri Oct 30 2015 ovitters <ovitters> 1.6.1-1.mga6
+ Revision: 896738
- new version 1.6.1

* Sun Sep 27 2015 tv <tv> 1.6.0-1.mga6
+ Revision: 884063
- adjust file list on ia32
- new release

* Tue Jun 30 2015 wally <wally> 1.4.5-3.mga6
+ Revision: 849036
- rebuild to get more typelib() requires

* Mon Jun 29 2015 wally <wally> 1.4.5-2.mga6
+ Revision: 847484
- add requires for gir pkg to devel pkg

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.4.5-1.mga6
+ Revision: 836949
- 1.4.5

* Sat Jun 20 2015 ovitters <ovitters> 1.4.4-1.mga6
+ Revision: 836306
- new version 1.4.4

* Wed Oct 15 2014 umeabot <umeabot> 1.4.3-2.mga5
+ Revision: 740917
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 wally <wally> 1.4.3-1.mga5
+ Revision: 731367
- new version 1.4.3

* Fri Sep 26 2014 wally <wally> 1.4.1-3.mga5
+ Revision: 724896
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-2.mga5
+ Revision: 679985
- Mageia 5 Mass Rebuild

* Thu Aug 28 2014 ovitters <ovitters> 1.4.1-1.mga5
+ Revision: 668983
- new version 1.4.1

* Tue Jul 29 2014 tv <tv> 1.4.0-2.mga5
+ Revision: 657828
- rebuild with fixed gcc (might fix ff & shotwell)

* Mon Jul 21 2014 fwang <fwang> 1.4.0-1.mga5
+ Revision: 654948
- update file list
- 1.4.0

* Sat Apr 19 2014 fwang <fwang> 1.2.4-1.mga5
+ Revision: 616973
- 1.2.4

* Sun Feb 09 2014 fwang <fwang> 1.2.3-1.mga5
+ Revision: 587302
- 1.2.3

* Thu Jan 23 2014 gw666 <gw666> 1.2.2-1.mga4
+ Revision: 567575
- new version (bug #12142)

* Sun Oct 20 2013 umeabot <umeabot> 1.2.0-2.mga4
+ Revision: 536825
- Mageia 4 Mass Rebuild

* Tue Sep 24 2013 ovitters <ovitters> 1.2.0-1.mga4
+ Revision: 485279
- new version 1.2.0

* Sat Sep 21 2013 fwang <fwang> 1.1.90-1.mga4
+ Revision: 483017
- use shipped autogen
- br autopoint
- use autoreconf
- add libsm
- update br
- add more br
- cleanup br
- update file list and br
- new version 1.1.90

* Thu Aug 29 2013 fwang <fwang> 1.0.10-1.mga4
+ Revision: 472793
- new version 1.0.10

* Thu Aug 01 2013 fwang <fwang> 1.0.9-1.mga4
+ Revision: 461935
- new version 1.0.9
+ ovitters <ovitters>
- new version 1.0.8

* Fri May 24 2013 fwang <fwang> 1.0.7-1.mga4
+ Revision: 425847
- new version 1.0.7

* Sat Jan 12 2013 umeabot <umeabot> 1.0.5-2.mga3
+ Revision: 352756
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 ovitters <ovitters> 1.0.5-1.mga3
+ Revision: 342905
- new version 1.0.5

* Thu Dec 20 2012 cjw <cjw> 1.0.4-1.mga3
+ Revision: 333463
- 1.0.4

* Fri Nov 23 2012 fwang <fwang> 1.0.3-1.mga3
+ Revision: 321178
- new version 1.0.3

* Thu Oct 25 2012 ovitters <ovitters> 1.0.2-1.mga3
+ Revision: 309971
- new version 1.0.2

* Mon Oct 08 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 303326
- update rpm group
+ ovitters <ovitters>
- new version 1.0.1

* Mon Sep 24 2012 fwang <fwang> 1.0.0-1.mga3
+ Revision: 297081
- new version 1.0.0

* Mon Sep 17 2012 ovitters <ovitters> 0.11.99-1.mga3
+ Revision: 295509
- new version 0.11.99

* Sat Sep 15 2012 fwang <fwang> 0.11.94-2.mga3
+ Revision: 294177
- rebuild for rpm gst1.0 provides

* Fri Sep 14 2012 fwang <fwang> 0.11.94-1.mga3
+ Revision: 293797
- update file list
- update file list
+ ovitters <ovitters>
- new version 0.11.94

* Wed Sep 05 2012 fwang <fwang> 0.11.93-4.mga3
+ Revision: 288325
- add plugins virtual provides

* Tue Sep 04 2012 fwang <fwang> 0.11.93-3.mga3
+ Revision: 287969
- fix libname

* Tue Sep 04 2012 fwang <fwang> 0.11.93-2.mga3
+ Revision: 287967
- add requires on libname
- update file list

* Tue Sep 04 2012 fwang <fwang> 0.11.93-1.mga3
+ Revision: 287961
- drop invalid br
- split out gir files
- update br
- cleanup spec
+ dmorgan <dmorgan>
- imported package gstreamer1.0-plugins-base

